/***********************************************************************
// Persistence of Vision Ray Tracer Scene Description File
// File name   : lorenz_macro.pov
// Version     : 3.6
// Description : The Lorenz attractor
// Date        : 23 November 2006
// Author      : John Guthkelch (Doctor John) <docjohn1 AT googlemail DOT com>
// Web Page    : 
// Altered     : 
// Changelog   : 
License & copyright:
(c) 2006 John Guthkelch
This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version. This program is distributed in the hope that
it will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
the GNU General Public License for more details.
(See http://www.gnu.org/licenses/gpl.txt for the full GPL text)

***********************************************************************/

#version 3.6;

#declare Radiosity=1;

global_settings {
	assumed_gamma 1.0
	max_trace_level 5
	adc_bailout 0.0039
	hf_gray_16 off
	max_intersections 64
	noise_generator 2
	#if (Radiosity)
		ambient_light 0
		radiosity {
			pretrace_start 0.08
			pretrace_end   0.02
			count 35 // Go higher to reduce blotchiness

			nearest_count 5
			error_bound 1.8 // Go lower for accuracy but increase count
			recursion_limit 3

			low_error_factor .5
			gray_threshold 0.0 // Increase to grey things down
			minimum_reuse 0.015
			
			//max_sample 
			brightness 1

			adc_bailout 0.01 // 0.01/Brightest_Ambient_Object
			always_sample on
			media off
			normal off
		}
	#end
}

camera {
	perspective
	location <0, 1, -10>
	angle 50
	right (image_width/image_height)*x
	look_at <0, 1, 0>
}

light_source {
	<10000, 10000, -10000>,
	rgb 1
}

sky_sphere {
	pigment {
		gradient y
		color_map {
			[0 color rgb 1]
			[1 color rgb <0.3, 0.3, 0.7>]
		}
		scale 2
		translate -1
	}
}

#macro Lorenz(a, b, c, dT, Iter, X0, Y0, Z0, R)
// Iter - number of iterations; the more the merrier but watch your memory usage!
// dT - step length (keep it small)
// a - the Prandtl number
// b - the Rayleigh number
// c - I suppose this has a name but I don't know it
// X0, Y0, Z0 - Starting location
// R - cylinder radius
	#local Count=0;
	#while (Count<Iter)
		#local X1=X0+dT*a*(Y0-X0);
		#local Y1=Y0+dT*(X0*(b-Z0)-Y0);
		#local Z1=Z0+dT*(X0*Y0-c*Z0);
		#if (Count>150) //Discard the first few iterations.
			cylinder {
				<X0,Y0,Z0>, <X1,Y1,Z1>, R
				pigment {
					color rgb <(1-2*(Count/Iter))*((Count/Iter)<0.5),
					((2*(Count/Iter)*((Count/Iter)<0.5))+(2*((1-(Count/Iter))*((Count/Iter)>=0.5)))),
					((2*(Count/Iter))-1)*((Count/Iter)>0.5)>
				}
			}
		#end
		#local Count=Count+1;
		#local X0=X1;
		#local Y0=Y1;
		#local Z0=Z1;
	#end
#end

Lorenz(10, 28, 8/3, 0.00055, 250000, 0.0001, 0.0001, 0.0001, 0.035)